# The CFELPyUtils Library

## Introduction

`cfel_fmt` is a fork of the [CFELPyUtils](https://cfel-sc-public.pages.desy.de/cfelpyutils/)
library developed at the Center For Free  Electron Laser Science (CFEL) in Hamburg.
It contains functions relating to parsing the text-based `.geom` file format
used by CrystFEL and certain other tools, and the CrystFEL stream output format.

### Features

- Reading CrystFEL detector geometry information
- Reading [CrystFEL](https://www.desy.de/~twhite/crystfel/) streams

## Installation

The `cfel_fmt` library is available on the [Python Package Index](https://pypi.org/)
(PyPI). It can be installed using the 'pip' command:

    pip install cfel_fmt

The library can also be installed manually by checking out this repository and running:

    pip install .

## Contributors

The CFELPyUtils library was developed in the lab of
[Henry Chapman](https://cid.cfel.de/) at the Center For Free Electron Laser Science
in Hamburg.

Many people from different institutions worlwide contribute code, testing and support
to the project:

* Valerio Mariani
* Anton Barty
* Andrew Morgan
* Thomas A. White
* Thomas Kluyver
* Philipp Middendorf
* Luca Gelisio
* Florian Lauck

If you have any questions or want to contribute, please [contact us](mailto:sc@cfel.de).

## Documentation

Documentation for `cfel_fmt` is available
[on Gitlab pages](https://dataanalysis.pages.xfel.eu/cfel_fmt/) and
in the [docs/](docs) of the [repository](https://gitlab.desy.de/cfel-sc-public/cfelpyutils).

## Source Code

The source code of `cfel_fmt` can be found on the EuXFEL GitLab instance:
https://git.xfel.eu/dataAnalysis/cfel_fmt#
